==> loncapa-2.3.0.tar.gz: loncapa-2.3.0/loncom/auth/localauth.pm <==
# The LON-CAPA dummy localauthentication mechnism
#
# $Id: localauth.pm,v 1.3 2006/08/25 21:35:52 albertel Exp $
#
# Copyright Michigan State University Board of Trustees
#
# This file is part of the LearningOnline Network with CAPA (LON-CAPA).
#
# LON-CAPA is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# LON-CAPA is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with LON-CAPA; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# /home/httpd/html/adm/gpl.txt
#
# http://www.lon-capa.org/
#
# 8/24 Guy Albertelli


package localauth;

# The localauth routine receives
# - the typed in username
# - the typed in password
# - the optional information that was stored when the authentication 
#   mechanism was specified 
# It is expected to return a 1 if the user is authenticated and a 0 otherwise
# ----START LOCAL CHANGES HERE ----- DON'T DELETE THIS LINE
sub localauth {
    my ($username,$password,$optional_argument) = @_;
    return 0;
}
# ----END LOCAL CHANGES HERE ----- DON'T DELETE THIS LINE

1;
__END__

==> loncapa-2.3.3.tar.gz: loncapa-2.3.3/loncom/auth/localauth.pm <==
# The LON-CAPA dummy localauthentication mechnism
#
# $Id: localauth.pm,v 1.4 2007/01/08 16:24:26 albertel Exp $
#
# Copyright Michigan State University Board of Trustees
#
# This file is part of the LearningOnline Network with CAPA (LON-CAPA).
#
# LON-CAPA is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# LON-CAPA is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with LON-CAPA; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# /home/httpd/html/adm/gpl.txt
#
# http://www.lon-capa.org/
#
# 8/24 Guy Albertelli


package localauth;

# The localauth routine receives
# - the typed in username
# - the typed in password
# - the optional information that was stored when the authentication 
#   mechanism was specified 
# It is expected to return a 1 if the user is authenticated and a 0 otherwise
# ----START LOCAL CHANGES HERE ----- DON'T DELETE THIS LINE
sub localauth {
    my ($username,$password,$optional_argument,$domain) = @_;
    return 0;
}
# ----END LOCAL CHANGES HERE ----- DON'T DELETE THIS LINE

1;
__END__
